<?php
namespace Elementor; 

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly	
}

/**
 *  Steps Box
*/
 
class Invess_Coverimgbox_Widget extends Widget_Base{

	public function get_name() {
		return 'tm_coverimgbox_element';
	}

	public function get_title() {
		return esc_attr__( 'Cover Box', 'inoterior' );
	}

	public function get_icon() {
		return ' eicon-menu-toggle';
	}

	public function get_categories() {
		return [ 'inoterior_category' ];
	}

	public function __construct($data = [], $args = null) {
		parent::__construct($data, $args);
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'data_section',
			[
				'label' => esc_attr__( 'Boxes Content', 'inoterior' ),
			]
        );

		$repeater = new Repeater();

		 $repeater->add_control(
			'icon_image',
			[
				'label' => __( 'Select Image for Icon', 'inoterior' ),
				'description' => __( 'image will appear at icon position', 'inoterior' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
			]
		);


		$repeater->add_control(
			'label',
			[
				'label' => esc_attr__( 'Box Title', 'inoterior' ),
				'type' => Controls_Manager::TEXT,
				'default' => esc_attr__( 'Box Title', 'inoterior' ),
				'placeholder' => esc_attr__( 'Box Title', 'inoterior' ),
				'label_block' => true,
			]
		);
		
		$repeater->add_control(
			'smalltext',
			[
				'label' => esc_attr__( 'Box Content', 'inoterior' ),
				'default' => esc_attr__( 'Box Content', 'inoterior' ),
				'placeholder' => esc_attr__( 'Box Content', 'inoterior' ),
				'type' => Controls_Manager::TEXTAREA,
				'show_label' => true,
			]
		);

		$repeater->add_control(
			'link_text',
			[
				'label' => esc_attr__( 'Link Text', 'inoterior' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'description' => esc_attr__( 'Like READ MORE text. This text will appear as link (fill link URL in below option).', 'inoterior' ),
				'placeholder' => esc_attr__( 'READ MORE', 'inoterior' ),
				'label_block' => true,
				'separator' => 'before',
			]
		);
		
		$repeater->add_control(
			'link_url',
			[
				'label' => esc_attr__( 'Link URL', 'inoterior' ),
				'description' => esc_attr__( 'Add link URL here.', 'inoterior' ),
				'type' => Controls_Manager::URL,
				'show_label' => true,
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);
        $this->add_control(
			'boxes',
			[
				'label'		=> esc_attr__( 'Boxes', 'inoterior' ),
				'type'		=> Controls_Manager::REPEATER,
				'fields'	=> $repeater->get_controls(),
				'default'	=> [
					[
						'image'		=> get_template_directory_uri() . '/images/placeholder.png',
						'label'		=> esc_attr__( 'This is first box', 'inoterior' ),
						'smalltext'	=> esc_attr__( 'This is small description', 'inoterior' ),
					],
					[
						'image'		=> get_template_directory_uri() . '/images/placeholder.png',
						'label'		=> esc_attr__( 'This is second box', 'inoterior' ),
						'smalltext'	=> esc_attr__( 'This is small description', 'inoterior' ),
					],
				],
				'title_field' => '{{{ label }}}',
			]
		);

		$this->end_controls_section();



	}

	protected function render() {

		$settings	= $this->get_settings_for_display();
		extract($settings);
		$return = '';
		$link_html = '';
		$image_html		= '' ;
		$column_class = '';
		?>


		<?php
			$col_start_div	= '';
			$col_end_div	= '';
					if( !empty($boxes) ){
						switch( count($boxes) ){
					case 1:
						$column_class = 'one';
					break;
					
					case 2:
						$column_class = 'two';
					break;
					
					case 3:
						$column_class	 = 'three';
					break;
					
					case 4:
					default:
						$column_class = 'four';
					break;
				}
			} ?>
<div class="tm_coverimgbox_wrapper tm-column-<?php echo esc_attr($column_class); ?>">


		<?php
		$count = 1;
		$accclass = '';
		foreach( $settings['boxes'] as $box ){

			$smalltext_html	= ( !empty($box['smalltext']) ) ? '<div class="themetechmount-static-box-desc">'.esc_html($box['smalltext']).'</div>' : '' ;
			$label_html		= ( !empty($box['label']) ) ? '<div class="tm-box-title"><h4>'.esc_html($box['label']).'</h4></div>' : '' ;

							$icon_image = '<img src="'.esc_url($box['icon_image']['url']).'" alt="'.esc_attr($box['label']).'" />';
							$icon = '<div class="tm-stepbox-imagebox"><div class="tm-ptable-icon-type-image">' . $icon_image . '</div></div>';
							
						
					

			$link_html = '';
			if( !empty($box['link_text']) && isset($box['link_url']['url']) && !empty($box['link_url']['url']) ){
				$text = $box['link_text'];
				$link_html = '<a class="tm-staticbox-more-link tm-more-button" href="' . esc_url( $box['link_url']['url'] ) . '" title="' . esc_attr( $text ) . '" target="' . ( (!empty($box['link_url']['is_external']) && $box['link_url']['is_external']==true) ? '_blank' : '_self' ) . '">' . esc_attr( $text ) . '</a>' ;
			}
					ob_start();
					
					include( get_template_directory() . '/template-parts/coverimgbox/coverimgbox-default.php' );
					include( get_template_directory() . '/template-parts/coverimgbox/coverimgbox-default2.php' );
					$return .= ob_get_contents();
					ob_end_clean();
		$count++;

		}		
		
		echo themetechmount_wp_kses($return);
		
		?>

		</div>

	    <?php
	}

	protected function _content_template() {}

}
// Register widget
Plugin::instance()->widgets_manager->register_widget_type( new Invess_Coverimgbox_Widget() );